//
//  AppDelegate.m
//  iOSSDKDemo
//
//  Created by Kiwi on 2018/1/16.
//  Copyright © 2018年 infocare. All rights reserved.
//

#import <EweiSDK/EweiSDK.h>
#import "AppDelegate.h"
#import "ViewController.h"

#define EweiSDKAppKey    @"请输入您SDK渠道配置的AppKey"
#define EweiSDKAppSecret @"请输入您SDK渠道配置的AppSecret"
#define EweiSDKDomain    @"请输入您帮助台地址 如 https://iosdemo.ewei.com"
#define EweiSDKAccount   @"请输入您的账号（用户email / 用户手机号 / external_id）"

@interface AppDelegate ()

@property (strong, nonatomic) UIActivityIndicatorView * indicatorView;

@end

@implementation AppDelegate

- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}


- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // Override point for customization after application launch.

    // add observer for new message
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(eweiAuthorizationFailedNotificationHandler:)
                                                 name:EHAuthorizeFailureNotification
                                               object:nil];
    
    // Initialize Ewei SDK
    NSLog(@"SDK version: %@", [EHSDKManager SDKVersion]);
    
    // set log enabled
    [[EHSDKManager defaultManager] setLoggingEnabled:YES];
    
    // register your app with appkey & appsecret
    [[EHSDKManager defaultManager] registerWithAppKey:EweiSDKAppKey appSecret:EweiSDKAppSecret domain:EweiSDKDomain];
    
    
    
    // Initialize Window & View Controller
    self.window = [[UIWindow alloc] initWithFrame:[[UIScreen mainScreen] bounds]];
    [self.window makeKeyAndVisible];
    self.window.rootViewController = [[UINavigationController alloc] initWithRootViewController:[[ViewController alloc] init]];
    
    // add activity indicator on window
    self.indicatorView = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    self.indicatorView.center = self.window.center;
    self.indicatorView.hidesWhenStopped = YES;
    [self.indicatorView startAnimating];
    [self.window addSubview:self.indicatorView];
    self.window.userInteractionEnabled = NO;
    
    // sign in
    NSString * account = EweiSDKAccount;
    [self reSigninEweiSDKWithAccount:account];
    
    return YES;
}

- (void)reSigninEweiSDKWithAccount:(NSString*)account {
    [[EHSDKManager defaultManager] signinWithAccount:account completion:^(BOOL succeeded) {
        if (succeeded) {
            // 登录成功，解锁页面 touch 事件
            [self.indicatorView stopAnimating];
            self.window.userInteractionEnabled = YES;
            
            // do something after sign in
            [[EHSDKManager defaultManager] startUnitTest];
        } else {
            
            // 登录失败，3 秒后重试
            [self performSelector:@selector(reSigninEweiSDKWithAccount:) withObject:account afterDelay:3];
        }
    }];
}



#pragma mark - Notifications

- (void)eweiAuthorizationFailedNotificationHandler:(NSNotification*)notification {
    // 授权失败
    // 需要重新调用登录授权
}

@end
