//
//  ArticleTopicsController.m
//  iOSSDKDemo
//
//  Created by Kiwi on 2018/3/15.
//  Copyright © 2018年 infocare. All rights reserved.
//

#import <EweiSDK/EweiSDK.h>
#import "ArticleTopicsController.h"
#import "ArticlesListController.h"

@interface ArticleTopicsController ()

@end

@implementation ArticleTopicsController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    if (!(self.title.length > 0)) {
        self.navigationItem.title = @"文章目录";
    }
    
    // setup table view
    self.clearsSelectionOnViewWillAppear = YES;
    self.tableView.rowHeight = 44;
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    
    // load all data if needed
    if (!self.contentArray) {
        __weak typeof(self) weakSelf = self;
        
        // load new data
        [EHHttpRequest requestAllArticleTopicsWithCompletion:^(NSArray<EHArticleTopic *> *result, NSError *error) {
            
            if (!error) {
                weakSelf.contentArray = result;
                [weakSelf.tableView reloadData];
            }
            
        }];
        
    }
}


#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.contentArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString * identifier = @"cell";
    UITableViewCell * cell = [tableView dequeueReusableCellWithIdentifier:identifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:identifier];
        
        // Configure the cell...
        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    }
    
    EHArticleTopic * item = [self.contentArray objectAtIndex:indexPath.row];
    cell.textLabel.text = item.name;
    
    return cell;
}


#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    EHArticleTopic * item = [self.contentArray objectAtIndex:indexPath.row];
    
    // show sub topics if exist
    if (item.subTopics.count > 0) {
        
        ArticleTopicsController * controller = [[ArticleTopicsController alloc] init];
        controller.title = item.name;
        controller.contentArray = item.subTopics;
        [self.navigationController pushViewController:controller animated:YES];
        
    } else {
        
        // otherwise show article list
        ArticlesListController * controller = [[ArticlesListController alloc] init];
        controller.articleTopic = item;
        [self.navigationController pushViewController:controller animated:YES];
        
    }
    
}

@end
