//
//  TicketsViewController.m
//  iOSSDKDemo
//
//  Created by Kiwi on 2018/1/25.
//  Copyright © 2018年 infocare. All rights reserved.
//

#import <EweiSDK/EweiSDK.h>
#import "TicketsViewController.h"

@interface TicketsViewController ()

@end

@implementation TicketsViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    self.navigationItem.title = @"工单列表";
    
    // setup table view
    self.clearsSelectionOnViewWillAppear = YES;
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"cell"];
    
    // init segmented control
    UISegmentedControl * segmentedControl = [[UISegmentedControl alloc] initWithItems:@[@"我的", @"抄送", @"组的", @"待评价"]];
    segmentedControl.selectedSegmentIndex = 0;
    self.navigationItem.titleView = segmentedControl;
    [segmentedControl addTarget:self action:@selector(segmentedControlSelectedIndexChange:) forControlEvents:UIControlEventValueChanged];
    self.segmentedControl = segmentedControl;
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    [self loadDataForIndex:self.segmentedControl.selectedSegmentIndex];
}


- (void)segmentedControlSelectedIndexChange:(UISegmentedControl*)sender {
    // should clean up tableview
    // should refresh data
    self.contentArray = nil;
    [self.tableView reloadData];
    [self loadDataForIndex:sender.selectedSegmentIndex];
}


- (void)loadDataForIndex:(NSInteger)index {
    // should refresh data for index
    // should disable segmented control before requests' completion
    __weak typeof(self) weakSelf = self;
    self.segmentedControl.enabled = NO;
    if (index == 0) {
        [EHHttpRequest requestMyTicketsWithPage:1 count:20 completion:^(NSArray<EHTicket *> * result, NSError * error) {
            weakSelf.segmentedControl.enabled = YES;
            if (!error) {
                weakSelf.contentArray = [result copy];
                [weakSelf.tableView reloadData];
            }
        }];
    } else if (index == 1) {
        [EHHttpRequest requestCCSTicketsWithPage:1 count:20 completion:^(NSArray<EHTicket *> * result, NSError * error) {
            weakSelf.segmentedControl.enabled = YES;
            if (!error) {
                weakSelf.contentArray = [result copy];
                [weakSelf.tableView reloadData];
            }
        }];
    } else if (index == 2) {
        [EHHttpRequest requestMyGroupTicketsWithPage:1 count:20 completion:^(NSArray<EHTicket *> * result, NSError * error) {
            weakSelf.segmentedControl.enabled = YES;
            if (!error) {
                weakSelf.contentArray = [result copy];
                [weakSelf.tableView reloadData];
            }
        }];
    } else if (index == 3) {
        [EHHttpRequest requestUnevaluatedTicketsWithPage:1 count:20 completion:^(NSArray<EHTicket *> * result, NSError * error) {
            weakSelf.segmentedControl.enabled = YES;
            if (!error) {
                weakSelf.contentArray = [result copy];
                [weakSelf.tableView reloadData];
            }
        }];
    }
}



#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.contentArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell * cell = [tableView dequeueReusableCellWithIdentifier:@"cell" forIndexPath:indexPath];
    
    // Configure the cell...
    EHTicket * item = [self.contentArray objectAtIndex:indexPath.row];
    
    NSString * subject = item.subject;
    
    static NSArray * statusesArr;
    if (statusesArr == nil) {
        statusesArr = @[@"[待受理]", @"[已受理]", @"[处理中]", @"[处理完毕]", @"[已关闭]", @"[暂停]", @"[隔离]"];
    }
    
    NSString * statusText = [NSString stringWithFormat:@"%@", [statusesArr objectAtIndex:item.status]];
    
    // show ticket content on cell
    cell.textLabel.text = [NSString stringWithFormat:@"%@ %@", statusText, subject];
    
    return cell;
}


#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    EHTicket * item = [self.contentArray objectAtIndex:indexPath.row];
    
    EHTicketViewController * ticketViewController = [[EHTicketViewController alloc] init];
    ticketViewController.ticket = item;
    
    [self.navigationController pushViewController:ticketViewController animated:YES];
}

@end
