//
//  ViewController.m
//  iOSSDKDemo
//
//  Created by Kiwi on 2018/1/16.
//  Copyright © 2018年 infocare. All rights reserved.
//

#import <EweiSDK/EweiSDK.h>
#import "ViewController.h"
#import "TicketsViewController.h"
#import "RecommendArticlesController.h"
#import "ArticleTopicsController.h"

@interface ViewController () <EHTicketAddControllerDelegate>

@property (assign, nonatomic) BOOL hasNewMessage;

@end

@implementation ViewController

- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    self.navigationItem.title = @"Ewei SDK";
    
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"cell"];
    
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    
    // add observer for new message
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(chatNewMessageNotificationHandler:)
                                                 name:EHNewChatMessageNotification
                                               object:nil];
}

- (void)viewDidDisappear:(BOOL)animated {
    [super viewDidDisappear:animated];
    [[NSNotificationCenter defaultCenter] removeObserver:self name:EHNewChatMessageNotification object:nil];
}



#pragma mark - UITableViewDataSource

- (NSInteger)tableView:(UITableView *)sender numberOfRowsInSection:(NSInteger)section {
    return 7;
}

- (UITableViewCell *)tableView:(UITableView *)sender cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell * cell = [sender dequeueReusableCellWithIdentifier:@"cell" forIndexPath:indexPath];
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    
    // clean up new message label
    [[cell.contentView viewWithTag:1001] removeFromSuperview];
    
    if (indexPath.row == 0) {
        cell.textLabel.text = @"在线客服";
        
        if (self.hasNewMessage) {
            UILabel * lab = [[UILabel alloc] initWithFrame:CGRectMake(sender.frame.size.width - 66, 12, 30, 20)];
            lab.backgroundColor = [UIColor redColor];
            lab.font = [UIFont systemFontOfSize:10];
            lab.tag = 1001;
            lab.text = @"New";
            lab.textAlignment = NSTextAlignmentCenter;
            lab.textColor = [UIColor whiteColor];
            [cell.contentView addSubview:lab];
        }
        
    } else if (indexPath.row == 1) {
        cell.textLabel.text = @"论坛帖子";
    } else if (indexPath.row == 2) {
        cell.textLabel.text = @"帮助文档";
    } else if (indexPath.row == 3) {
        cell.textLabel.text = @"提交工单";
    } else if (indexPath.row == 4) {
        cell.textLabel.text = @"查询工单";
    } else if (indexPath.row == 5) {
        cell.textLabel.text = @"推荐文章";
    } else if (indexPath.row == 6) {
        cell.textLabel.text = @"文章目录";
    }
    return cell;
}


#pragma mark - UITableViewDelegate

- (void)tableView:(UITableView *)sender didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [sender deselectRowAtIndexPath:indexPath animated:YES];
    if (indexPath.row == 0) {
        
        // 隐藏新消息提示
        self.hasNewMessage = NO;
        [self.tableView reloadRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationNone];
        
        // 进入在线客服页面
        EHChatViewController * controller = [[EHChatViewController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    } else if (indexPath.row == 1) {
        
        // 进入论坛页面
        EHForumViewController * controller = [[EHForumViewController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    } else if (indexPath.row == 2) {
        
        // 进入文章页面
        EHHelpViewController * controller = [[EHHelpViewController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    } else if (indexPath.row == 3) {
        
        // 进入提交工单页面
        EHTicketAddController * controller = [[EHTicketAddController alloc] init];
        controller.delegate = self;
        [self.navigationController presentViewController:controller animated:YES completion:nil];
        
    } else if (indexPath.row == 4) {
        
        // 进入查询工单页面
        TicketsViewController * controller = [[TicketsViewController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    } else if (indexPath.row == 5) {
        
        // 进入推荐文章页面
        RecommendArticlesController * controller = [[RecommendArticlesController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    } else if (indexPath.row == 6) {
        
        // 进入文章目录页面
        ArticleTopicsController * controller = [[ArticleTopicsController alloc] init];
        [self.navigationController pushViewController:controller animated:YES];
        
    }
}


#pragma mark - EHTicketAddControllerDelegate

- (void)EHTicketAddControllerDidComplete:(EHTicketAddController*)controller ticket:(EHTicket*)ticket {
    // 工单提交成功
    
    [controller dismissViewControllerAnimated:YES completion:^{
        
        UIAlertController * alert = [UIAlertController alertControllerWithTitle:@"工单提交成功!" message:nil preferredStyle:UIAlertControllerStyleAlert];
        [alert addAction:[UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:nil]];
        [self presentViewController:alert animated:YES completion:nil];
        
        /*
         EHTicketViewController * ticketViewController = [[EHTicketViewController alloc] initWithTicket:ticket];
         [self.navigationController pushViewController:ticketViewController animated:YES];
         */
        
    }];

}


#pragma mark - Notifications

- (void)chatNewMessageNotificationHandler:(NSNotification*)notification {
    // 显示新消息提示
    self.hasNewMessage = YES;
    [self.tableView reloadRowsAtIndexPaths:@[[NSIndexPath indexPathForRow:0 inSection:0]] withRowAnimation:UITableViewRowAnimationNone];
}

@end
